@@ -11,7 +11,7 @@ use base 'App::Pinto::Command';
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.065_02'; # VERSION
+our $VERSION = '0.065_03'; # VERSION
 
 #------------------------------------------------------------------------------
 
@@ -54,7 +54,7 @@ __END__
 
 =pod
 
-=for :stopwords Jeffrey Thalhammer Imaginative Software Systems unmark unmarks
+=for :stopwords Jeffrey Ryan Thalhammer Imaginative Software Systems unmark unmarks
 
 =head1 NAME
 
@@ -62,7 +62,7 @@ App::Pinto::Command::default - mark the default stack
 
 =head1 VERSION
 
-version 0.065_02
+version 0.065_03
 
 =head1 SYNOPSIS
 
@@ -109,7 +109,7 @@ when the C<STACK> argument is specified.
 
 =head1 AUTHOR
 
-Jeffrey Thalhammer <jeff@imaginative-software.com>
+Jeffrey Ryan Thalhammer <jeff@stratopan.com>
 
 =head1 COPYRIGHT AND LICENSE
 
