@@ -11,7 +11,7 @@ use base 'App::Pinto::Command';
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.065_02'; # VERSION
+our $VERSION = '0.065_03'; # VERSION
 
 #------------------------------------------------------------------------------
 
@@ -64,7 +64,7 @@ __END__
 
 =pod
 
-=for :stopwords Jeffrey Thalhammer Imaginative Software Systems exe cpanm
+=for :stopwords Jeffrey Ryan Thalhammer Imaginative Software Systems exe cpanm
 
 =head1 NAME
 
@@ -72,7 +72,7 @@ App::Pinto::Command::install - install stuff from the repository
 
 =head1 VERSION
 
-version 0.065_02
+version 0.065_03
 
 =head1 SYNOPSIS
 
@@ -221,7 +221,7 @@ behavior is unspecified.
 
 =head1 AUTHOR
 
-Jeffrey Thalhammer <jeff@imaginative-software.com>
+Jeffrey Ryan Thalhammer <jeff@stratopan.com>
 
 =head1 COPYRIGHT AND LICENSE
 
